@@ -103,7 +103,7 @@ class Polynomial2D:
             tmpx2 = self.rescale['X2'].transform(self.data['X2'])
             tmpy = self.rescale['Y'].transform(self.data['Y'])
             tmpm = self.data['MASK'].copy()
-            newobj = Polynomial2D(x1=tmpx1,x2=tmpx2,y=tmpy,mask=mask)
+            newobj = Polynomial2D(x1=tmpx1,x2=tmpx2,y=tmpy,mask=tmpm)
             newobj.model = copy.deepcopy(self.model)
         else:
             newobj = copy.deepcopy(self)
